==> haskell-attoparsec-aeson-2.1.0.0-37-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:               attoparsec-aeson
version:            2.1.0.0
visibility:         public
id:                 attoparsec-aeson-2.1.0.0-Dv7oW4CsUXjKQqMNZaLFPh
key:                attoparsec-aeson-2.1.0.0-Dv7oW4CsUXjKQqMNZaLFPh
license:            BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:         Oleg Grenrus <oleg.grenrus@iki.fi>
author:             Bryan O'\''Sullivan <bos@serpentine.com>
stability:          experimental
homepage:           https://github.com/haskell/aeson
synopsis:           Parsing of aeson'\''s Value with attoparsec
description:
    Parsing of aeson'\''s Value with attoparsec, originally from aeson.

    This version is an empty package with bounds on @aeson@
    which has "Data.Aeson.Parser" module.
    This way e.g. specifying

    @
    build-depends: aeson >= 1.4.1.0 && \<2.3, attoparsec-aeson >=2.1.0.0 && \<2.3
    @

    will have "Data.Aeson.Parser" available for all @aeson@ versions in range.

category:           Parsing
abi:                2881cf8549be49b0dd5a86a4989e8cd2
exposed:            True
data-dir:           /usr/share/haskell-attoparsec-aeson
depends:            aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr base-4.16.4.0
haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-aeson/html/attoparsec-aeson.haddock

haddock-html:       /usr/share/doc/haskell-attoparsec-aeson/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-attoparsec-aeson-2.1.0.0-84.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-attoparsec-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:               attoparsec-aeson
version:            2.1.0.0
visibility:         public
id:                 attoparsec-aeson-2.1.0.0-DLZHWVleO2u5JH6RUsnj4T
key:                attoparsec-aeson-2.1.0.0-DLZHWVleO2u5JH6RUsnj4T
license:            BSD-3-Clause
copyright:
    (c) 2011-2016 Bryan O'\''Sullivan
    (c) 2011 MailRank, Inc.

maintainer:         Oleg Grenrus <oleg.grenrus@iki.fi>
author:             Bryan O'\''Sullivan <bos@serpentine.com>
stability:          experimental
homepage:           https://github.com/haskell/aeson
synopsis:           Parsing of aeson'\''s Value with attoparsec
description:
    Parsing of aeson'\''s Value with attoparsec, originally from aeson.

    This version is an empty package with bounds on @aeson@
    which has "Data.Aeson.Parser" module.
    This way e.g. specifying

    @
    build-depends: aeson >= 1.4.1.0 && \<2.3, attoparsec-aeson >=2.1.0.0 && \<2.3
    @

    will have "Data.Aeson.Parser" available for all @aeson@ versions in range.

category:           Parsing
abi:                12d776480acf79c658d9432f8261bf55
exposed:            True
data-dir:           /usr/share/haskell-attoparsec-aeson
depends:            aeson-2.1.2.1-38LADbNStwmEfKOReucTQy base-4.17.2.1
haddock-interfaces:
    /usr/share/doc/haskell-attoparsec-aeson/html/attoparsec-aeson.haddock

haddock-html:       /usr/share/doc/haskell-attoparsec-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
